@@ -1,8 +1,5 @@
-// Copyright (C) 2010 NICTA and the authors listed below
-// http://nicta.com.au
-// 
-// Authors:
-// - Conrad Sanderson (conradsand at ieee dot org)
+// Copyright (C) 2010 NICTA (www.nicta.com.au)
+// Copyright (C) 2010 Conrad Sanderson
 // 
 // This file is part of the Armadillo C++ library.
 // It is provided without any warranty of fitness
@@ -395,7 +392,7 @@ eglue_core<eglue_type>::apply(Cube<typename T1::elem_type>& out, const eGlueCube
   else if(is_same_type<eglue_type, eglue_schur>::value == true) { arma_applier(*); }
   else
     {
-    arma_stop("eglue_core::apply_proxy(): unhandled eglue_type");
+    arma_stop("eglue_core::apply(): unhandled eglue_type");
     }
   }
 
